pub struct RustTestSerdeFieldPayload {
pub kind: RustTestSerdeFieldKind,
pub label: String,
pub values: Vec<f64>,
}Expand description
Plain Serde payload stored inside custom data without its own timestamps.
Fields
kind: RustTestSerdeFieldKindlabel: Stringvalues: Vec<f64>Trait Implementations
Sourceimpl Clone for RustTestSerdeFieldPayload
impl Clone for RustTestSerdeFieldPayload
Sourcefn clone(&self) -> RustTestSerdeFieldPayload
fn clone(&self) -> RustTestSerdeFieldPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RustTestSerdeFieldPayload
impl Debug for RustTestSerdeFieldPayload
Sourceimpl<'de> Deserialize<'de> for RustTestSerdeFieldPayload
impl<'de> Deserialize<'de> for RustTestSerdeFieldPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RustTestSerdeFieldPayload
impl PartialEq for RustTestSerdeFieldPayload
Sourcefn eq(&self, other: &RustTestSerdeFieldPayload) -> bool
fn eq(&self, other: &RustTestSerdeFieldPayload) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RustTestSerdeFieldPayload